@@ -1,7 +1,13 @@
 modems = {
     "2c7c": { # Quectel VENDOR_ID
-        "EG25": { # Modem Name
+        "EC25": { # Modem Name
             "0125": ["02"] # USB_COMPOSITION_ID
+        },
+        "BG96": { # Modem Name
+            "0296": ["02"] # USB_COMPOSITION_ID
+        },
+        "BG95": { # Modem Name
+            "0296": ["02"] # USB_COMPOSITION_ID
         }
     },
     "1bc7": { # Telit VENDOR_ID
